@@ -600,10 +600,14 @@ class Model(ABC):
         )
         fig.subplots_adjust(hspace=.02, wspace=.02)
 
+        fitted_temps = [
+            model.fit_temperature for model in models if model.fit_status
+        ]
+
         ratio = np.linspace(0, 1, np.sum(
             [model.fit_status for model in models])
         )
-        colors = cm.get_cmap('coolwarm', 100)
+        colors = cm.get_cmap('coolwarm', len(fitted_temps))
 
         # Experimental data
         count = -1
@@ -642,12 +646,8 @@ class Model(ABC):
                 color=colors(ratio[count]),
                 lw=1
             )
-
+        
         # Find min and max fitted temperatures
-        fitted_temps = [
-            model.fit_temperature for model in models if model.fit_status
-        ]
-
         min_T = round(min(fitted_temps), 2)
         max_T = round(max(fitted_temps), 2)
 
@@ -655,12 +655,12 @@ class Model(ABC):
         # Norm creates an indexing for the colourmap values
         # i.e. what do the start and end correspond to
         norm = mpl_col.BoundaryNorm(
-            np.linspace(min_T, max_T),
+            np.linspace(min_T-0.000001, max_T+0.000001, len(fitted_temps)+1),
             ncolors=colors.N
         )
 
         # Scalar mappable converts colourmap numbers into an image of colours
-        sm = plt.cm.ScalarMappable(cmap=colors, norm=norm)
+        sm = cm.ScalarMappable(cmap=colors, norm=norm)
 
         colourbar_ticks = ut.get_temp_colourbar_ticks(fitted_temps)
 
@@ -765,10 +765,14 @@ class Model(ABC):
         ax1.xaxis.set_ticks_position('top')
         ax2.xaxis.set_major_formatter(mtick.FormatStrFormatter('%.1f'))
 
+        fitted_temps = [
+            model.fit_temperature for model in models if model.fit_status
+        ]
+
         ratio = np.linspace(0, 1, np.sum(
             [model.fit_status for model in models])
         )
-        colors = cm.get_cmap('coolwarm', 100)
+        colors = cm.get_cmap('coolwarm', len(fitted_temps))
 
         # Experimental data
         count = -1
@@ -827,10 +831,6 @@ class Model(ABC):
         ax3.get_shared_x_axes().join(ax2, ax3)
 
         # Find min and max fitted temperatures
-        fitted_temps = [
-            model.fit_temperature for model in models if model.fit_status
-        ]
-
         min_T = round(min(fitted_temps), 2)
         max_T = round(max(fitted_temps), 2)
 
@@ -838,11 +838,11 @@ class Model(ABC):
         # Norm creates an indexing for the colourmap values
         # i.e. what do the start and end correspond to
         norm = mpl_col.BoundaryNorm(
-            np.linspace(min_T, max_T),
+            np.linspace(min_T-0.000001, max_T+0.000001, len(fitted_temps)+1),
             ncolors=colors.N
         )
         # Scalar mappable converts colourmap numbers into an image of colours
-        sm = plt.cm.ScalarMappable(cmap=colors, norm=norm)
+        sm = cm.ScalarMappable(cmap=colors, norm=norm)
 
         colourbar_ticks = ut.get_temp_colourbar_ticks(fitted_temps)
 
@@ -1049,6 +1049,7 @@ class DebyeModel(Model):
 
         return
 
+    @staticmethod
     def write_fit_params(models: list[Model], file_name: str):
         """
         Writes fitted parameters of models to file
@@ -1069,6 +1070,8 @@ class DebyeModel(Model):
         f.write(models[0].FITHEADERS)
 
         for model in models:
+            if not model.fit_status:
+                continue
             f.write('{: 8.6f}   '.format(model.fit_temperature))
             for j in range(len(model.fitted_params)):
                 f.write('   {: 12.8E}   {: 12.8E}'.format(
@@ -1781,7 +1784,8 @@ class Experiment():
     @classmethod
     def from_measurements(cls,
                           measurements: list[Measurement],
-                          temp_thresh: float = 0.1) -> list['Experiment']:
+                          temp_thresh: float = 0.1,
+                          field_thresh: float = 1e-8) -> list['Experiment']:
         """
         Creates list of Experiment objecst from a list of individual
         Measurement objects. Experiments are defined as a set of measurements
@@ -1793,6 +1797,8 @@ class Experiment():
             Measurements at various temperatures and DC fields
         temp_thresh: float, default 0.1
             Threshold used to discriminate between temperatures
+        field_thresh: float, default 1e-8
+            Threshold used to discriminate between dc field values
 
         Returns
         -------
@@ -1812,114 +1818,96 @@ class Experiment():
         # Sort measurements by dc field
         measurements.sort(key=lambda k: (k.dc_field, k.temperature))
 
-        mean_temps, split_ind = find_mean_temperatures(
-            [
-                measurement.temperature
-                for measurement in measurements
-            ],
-            temp_thresh=temp_thresh
-        )
-
-        # Set each measurement's "mean", or representative temperature
-        for measurement, mean_temp in zip(measurements, np.concatenate(mean_temps)): # noqa
-            measurement.set_mean_temp(mean_temp)
-
-        # sort measurements by field, then temperature, then by ac frequency
-        measurements.sort(
-            key=lambda k: (k.dc_field, k.mean_temperature, k.ac_freq)
-        )
-
-        raw_temperatures = [
-            measurement.temperature
-            for measurement in measurements
-        ]
-
-        sus_res = np.split(
-            [
-                measurement.sus_re
-                for measurement in measurements
-            ],
-            split_ind + 1
-        )
-
-        sus_ims = np.split(
-            [
-                measurement.sus_im
-                for measurement in measurements
-            ],
-            split_ind + 1
-        )
-
-        ac_freqs = np.split(
-            [
-                measurement.ac_freq
-                for measurement in measurements
-            ],
-            split_ind + 1
-        )
-
-        dc_fields = np.split(
-            [
-                measurement.dc_field
-                for measurement in measurements
-            ],
-            split_ind + 1
-        )
-
-        experiments = [
-            cls(
-                mean_temp, raw_temp, sus_re, sus_im, ac_freq,
-                dc_field[0]
-            )
-            for (
-                    mean_temp, raw_temp, sus_re, sus_im, ac_freq,
-                    dc_field
-                ) in zip(
-                    mean_temps, raw_temperatures, sus_res,
-                    sus_ims, ac_freqs, dc_fields
-                )
-        ]
-
-        return experiments
-
-    @staticmethod
-    def split_by_field(experiments: list['Experiment'],
-                       field_thresh: float = 1e-8) -> list[list['Experiment']]:
-        """
-        Splits list of experiments into list of lists based on DC field value
-
-        Parameters
-        ----------
-        experiments: list[Experiment]
-            Experiments, ordered low to high DC field then
-            low to high temperature
-            e.g.
-            0.1 Oe 25 K
-            0.1 Oe 50 K
-            ...
-            0.5 Oe 25 K
-            0.5 Oe 50 K
-        field_thresh: float, default 1e-8 Oe
-            Threshold used to discriminate between DC Field values
-
-        Returns
-        -------
-        list[list[Experiment]]
-            Experiment grouped by DC field value, ordered low to high
-
-        """
-
-        # Find values for which step size is >= field_thresh Oe
+        # Find values for which dc field step size is >= field_thresh Oe
         mask = np.abs(
-            np.diff([experiment.dc_field for experiment in experiments])
+            np.diff([measurement.dc_field for measurement in measurements])
         ) >= field_thresh
         # and mark indices at which to split
         split_ind = np.where(mask)[0]
 
-        experiments: list[list[Experiment]] = np.split(
-            experiments, split_ind + 1
+        measurements: list[list[Measurement]] = np.split(
+            measurements, split_ind + 1
         )
 
+        measurements = [measurements.tolist() for measurements in measurements]
+
+        experiments = []
+
+        for sf_measurments in measurements:
+
+            mean_temps, split_ind = find_mean_temperatures(
+                [
+                    measurement.temperature
+                    for measurement in sf_measurments
+                ],
+                temp_thresh=temp_thresh
+            )
+
+            # Set each measurement's "mean", or representative temperature
+            for measurement, mean_temp in zip(sf_measurments, np.concatenate(mean_temps)): # noqa
+                measurement.set_mean_temp(mean_temp)
+
+            # sort measurements by temperature, then by ac frequency
+            sf_measurments.sort(
+                key=lambda k: (k.mean_temperature, k.ac_freq)
+            )
+
+            raw_temperatures = [
+                measurement.temperature
+                for measurement in sf_measurments
+            ]
+
+            raw_temperatures = np.split(
+                raw_temperatures,
+                split_ind + 1
+            )
+
+            sus_res = np.split(
+                [
+                    measurement.sus_re
+                    for measurement in sf_measurments
+                ],
+                split_ind + 1
+            )
+
+            sus_ims = np.split(
+                [
+                    measurement.sus_im
+                    for measurement in sf_measurments
+                ],
+                split_ind + 1
+            )
+
+            ac_freqs = np.split(
+                [
+                    measurement.ac_freq
+                    for measurement in sf_measurments
+                ],
+                split_ind + 1
+            )
+
+            dc_fields = np.split(
+                [
+                    measurement.dc_field
+                    for measurement in sf_measurments
+                ],
+                split_ind + 1
+            )
+
+            experiments.append([
+                cls(
+                    mean_temp, raw_temp, sus_re, sus_im, ac_freq,
+                    dc_field[0]
+                )
+                for (
+                        mean_temp, raw_temp, sus_re, sus_im, ac_freq,
+                        dc_field
+                    ) in zip(
+                        mean_temps, raw_temperatures, sus_res,
+                        sus_ims, ac_freqs, dc_fields
+                    )
+            ])
+
         return experiments
 
     @staticmethod
@@ -1961,8 +1949,13 @@ class Experiment():
         ax1.xaxis.set_ticks_position('top')
         ax2.xaxis.set_major_formatter(mtick.FormatStrFormatter('%.1f'))
 
+        # Find min and max fitted temperatures
+        fitted_temps = [
+            experiment.temperatures[0] for experiment in experiments
+        ]
+
         ratio = np.linspace(0, 1, len(experiments))
-        colors = cm.get_cmap('coolwarm', 100)
+        colors = cm.get_cmap('coolwarm', len(fitted_temps))
 
         # Experimental data
         count = -1
@@ -1994,11 +1987,6 @@ class Experiment():
         # Do not share ax3 as it is linear and these are log
         ax3.get_shared_x_axes().join(ax2, ax3)
 
-        # Find min and max fitted temperatures
-        fitted_temps = [
-            experiment.temperatures[0] for experiment in experiments
-        ]
-
         min_T = round(min(fitted_temps), 2)
         max_T = round(max(fitted_temps), 2)
 
@@ -2006,11 +1994,11 @@ class Experiment():
         # Norm creates an indexing for the colourmap values
         # i.e. what do the start and end correspond to
         norm = mpl_col.BoundaryNorm(
-            np.linspace(min_T, max_T),
+            np.linspace(min_T-0.000001, max_T+0.000001, len(fitted_temps)+1),
             ncolors=colors.N
         )
         # Scalar mappable converts colourmap numbers into an image of colours
-        sm = plt.cm.ScalarMappable(cmap=colors, norm=norm)
+        sm = cm.ScalarMappable(cmap=colors, norm=norm)
 
         colourbar_ticks = ut.get_temp_colourbar_ticks(fitted_temps)
 
@@ -2099,8 +2087,12 @@ class Experiment():
         )
         fig.subplots_adjust(hspace=.02, wspace=.02)
 
+        fitted_temps = [
+            experiment.temperatures[0] for experiment in experiments
+        ]
+
         ratio = np.linspace(0, 1, len(experiments))
-        colors = cm.get_cmap('coolwarm', 100)
+        colors = cm.get_cmap('coolwarm', len(fitted_temps))
 
         # Experimental data
         for eit, experiment in enumerate(experiments):
@@ -2117,9 +2109,6 @@ class Experiment():
             )
 
         # Find min and max fitted temperatures
-        fitted_temps = [
-            experiment.temperatures[0] for experiment in experiments
-        ]
 
         min_T = round(min(fitted_temps), 2)
         max_T = round(max(fitted_temps), 2)
@@ -2128,12 +2117,12 @@ class Experiment():
         # Norm creates an indexing for the colourmap values
         # i.e. what do the start and end correspond to
         norm = mpl_col.BoundaryNorm(
-            np.linspace(min_T, max_T),
+            np.linspace(min_T-0.000001, max_T+0.000001, len(fitted_temps)+1),
             ncolors=colors.N
         )
 
         # Scalar mappable converts colourmap numbers into an image of colours
-        sm = plt.cm.ScalarMappable(cmap=colors, norm=norm)
+        sm = cm.ScalarMappable(cmap=colors, norm=norm)
 
         colourbar_ticks = ut.get_temp_colourbar_ticks(fitted_temps)
 
@@ -2302,19 +2291,10 @@ def interactive_t_select(experiments: list[Experiment]):
     Parameters
     ----------
         experiments: list[Experiment]
-            Experiments, ordered low to high DC field then
-            low to high temperature
-            e.g.
-            0.1 Oe 25 K
-            0.1 Oe 50 K
-            ...
-            0.5 Oe 25 K
-            0.5 Oe 50 K
+            Experiments, ordered  low to high temperature
 
     Returns
     -------
-        Parameters
-    ----------
         list[Experiment]
             Same as before, with user-specified entries removed
     """
@@ -2374,11 +2354,9 @@ def interactive_t_select(experiments: list[Experiment]):
         )
 
     # Remove empty axes
-    for ait in range(n_temps, len(axs)):
-        fig.delaxes(axs[ait])
-
-    for ait in range(n_temps, len(axs)):
-        axs = np.delete(axs, ait)
+    for _ in range(len(axs)-n_temps):
+        fig.delaxes(axs[-1])
+        axs = np.delete(axs, -1)
 
     for ax in axs:
         ax.set_facecolor("Green")
