@@ -97,7 +97,7 @@ def ac_mode_func(args):
             )
         exit()
 
-    # Manual selection of temperatures to git
+    # Manual selection of temperatures to fit
     if args.select_T:
         all_experiments_sep = [
             ac.interactive_t_select(experiments)
@@ -105,24 +105,25 @@ def ac_mode_func(args):
         ]
         args.discard_off = True
 
-    # Generate a model object for each experiment, separated by dc field
-    # strength
-    all_models_sep = [
-        ac.Model.from_experiments(experiments)
-        for experiments in all_experiments_sep
-    ]
+    unique_dc_fields = np.unique(
+        [experiment[0].dc_field for experiment in all_experiments_sep]
+    )
 
-    # Update flat lines threshold
-    for models in all_models_sep:
+    # Eventual list of all models separated by dc_field
+    all_models_sep = []
+
+    # For each experiment, fit a model to the data
+    for experiments, dc_field in zip(all_experiments_sep, unique_dc_fields):
+
+        # Creates models for current experiments
+        models = ac.Model.from_experiments(experiments)
+        # Update flat lines threshold
         for model in models:
             model.flat_thresh = args.flat_thresh
 
-    # For each experiment, fit the model to the data
-    # Feed fits forward in temperature
-    # Use T=n fit for T=n+1 guess
-    for models, experiments in zip(all_models_sep, all_experiments_sep):
+        # Feed fits forward in temperature
+        # Use T=n fit for T=n+1 guess
         for it, (model, experiment) in enumerate(zip(models, experiments)):
-
             # Start with fixed guess of parameters
             if it == 0:
                 prev_fit = model.initial_params
@@ -137,12 +138,8 @@ def ac_mode_func(args):
             else:
                 prev_fit = model.initial_params
 
-    unique_dc_fields = np.unique(
-        [experiment[0].dc_field for experiment in all_experiments_sep]
-    )
-
-    # For each field, save to file all associated fit params and model funcs
-    for models, experiments, dc_field in zip(all_models_sep, all_experiments_sep, unique_dc_fields): # noqa
+        # For each field, save to file all associated fit params and model
+        # funcs
         base_filename = 'ac_model_{}_1sigma_{:.5f}Oe'.format(
             models[0].NAME.replace(" ", "_"),
             dc_field
@@ -177,10 +174,14 @@ def ac_mode_func(args):
             file_head="ac"
         )
 
-        # Proceed to fit the relaxation profile after having finished fitting
-        # the AC data.
         if args.process == 'susc':
-            continue
+            exit()
+
+        all_models_sep.append(models)
+
+    # Proceed to fit the relaxation profile after having finished fitting
+    # the AC data.
+    for models, experiments, dc_field in zip(all_models_sep, all_experiments_sep, unique_dc_fields): # noqa
 
         print()
         print(
@@ -227,6 +228,9 @@ def ac_mode_func(args):
 
         # Select the model function to be used.
         # Set field to zero so Direct is never activated in AC module.
+
+        if np.abs(dc_field) < args.zf_cutoff:
+            dc_field = 0.
         relax.select_model_rates(
             rxp, temperature, 1./tau, dc_field, _process='tau_vs_T'
         )
@@ -569,6 +573,13 @@ def read_args(arg_list=None):
         default=1e-8,
         help='Threshold used to discriminate between DC Fields, default 1e-8 Oe' # noqa
     )
+    ac_parser.add_argument(
+        '--zf_cutoff',
+        metavar='<float>',
+        type=float,
+        default=5,
+        help='DC Field with smaller absolute valuesthan this will be considered to be zero, default 5 Oe' # noqa
+    )
     ac_parser.add_argument(
         '--select_T',
         action='store_true',
